import React, {PureComponent} from "react"
import mainApi from "./../../../api/mainApi"
import {serialize, original, validator} from "./../../../functions/helper"
import Swal from "sweetalert2"
import LoadingElement from "./../../loadings/LoadingElement"
import Validation from "./../../../modules/Validation"

class ChangePasswordForm extends PureComponent
{
    state = {
        data: { id: 1590, sp_param: '', Login_User_Token: '', Login_User_cp: ''},

        dataInit: {
            username: '',
            old: '',
            newPass: '',
            confirm: ''
        },

        errors: {},
        
        loadingStatus: false
    }

    render()
    {
        let {loadingStatus, errors} = this.state

        return (
            <>
                <h4 className="text-muted text-right">
                    <i className="ion-android-lock"></i>
                    تغییر رمز عبور
                </h4>

                <hr />

                <div className="row">
                    <div className="col-lg-6">
                        <div className="form-group text-right">
                            <label className="text-muted">رمز قدیم</label>
                            <input onChange={(e) => this.oldHandler(e)} value={this.state.dataInit.old} type="password" className="form-control form-control-lg text-left" style={{direction: "ltr"}} disabled={loadingStatus ? 'disabled' : ''} />
                            {
                                errors.hasOwnProperty('old')
                                    ? <small className="text-danger my-animate-element">{errors.old}</small>
                                    : ""
                            }
                        </div>
                    </div>
                </div>

                <div className="row">
                    <div className="col-lg-6">
                        <div className="form-group text-right">
                            <label className="text-muted">رمز جدید</label>
                            <input onChange={(e) => this.newPassHandler(e)} value={this.state.dataInit.newPass} type="password" className="form-control form-control-lg text-left" style={{direction: "ltr"}} disabled={loadingStatus ? 'disabled' : ''} />
                            {
                                errors.hasOwnProperty('newPass')
                                    ? <small className="text-danger my-animate-element">{errors.newPass}</small>
                                    : ""
                            }
                            <div className="text-info small">رمز عبور حداقل باید 4 حرف باشد.</div>
                        </div>
                    </div>
                </div>

                <div className="row">
                    <div className="col-lg-6">
                        <div className="form-group text-right">
                            <label className="text-muted">تکرار رمز جدید</label>
                            <input onChange={(e) => this.confirmHandler(e)} value={this.state.dataInit.confirm} type="password" className="form-control form-control-lg text-left" style={{direction: "ltr"}} disabled={loadingStatus ? 'disabled' : ''} />
                            {
                                errors.hasOwnProperty('confirm')
                                    ? <small className="text-danger my-animate-element">{errors.confirm}</small>
                                    : ""
                            }
                        </div>
                    </div>
                </div>

                <div className="row mt-3">
                    <div className="col-lg-2">
                        <div className="form-group text-right">
                            <button onClick={() => this.submitHandler()} className="btn btn-lg btn-block btn-success" disabled={loadingStatus ? 'disabled' : ''}>
                                {
                                    loadingStatus 
                                        ?	<LoadingElement varient="button" />
                                        :	"ثبت"
                                }
                            </button>
                        </div>
                    </div>
                </div>
            </>
        )
    }

    oldHandler(e){this.setState({dataInit: {...this.state.dataInit, old: e.target.value}})}
    newPassHandler(e){this.setState({dataInit: {...this.state.dataInit, newPass: e.target.value}})}
    confirmHandler(e){this.setState({dataInit: {...this.state.dataInit, confirm: e.target.value}})}

    submitHandler()
    {
        let valid = Validation.make(this.state.dataInit, [
			{old: ["required", "min:4"]},
			{newPass: ["required", "min:4"]},
			{confirm: ["required", "min:4"]}
		])

		if (! valid) {
			this.setState({errors: Validation.getErrors()})
			Swal.fire({position: "bottom", html: `<i class="ion-android-warning text-danger"></i><span class="text-muted">خطا های فرم را بر طرف نمایید.</span>`, showConfirmButton: false, timer: 2000})
			return
		}

        this.setState({errors: {}})
        
        this.state.data.Login_User_Token = window.localStorage.getItem('user_login_token')
        this.state.data.Login_User_cp = window.localStorage.getItem('user_login_cp')
        this.state.dataInit.username = window.localStorage.getItem('username')

        let {username, old, newPass, confirm} = this.state.dataInit
        this.state.data.sp_param = `'${username}','${old}','${newPass}','${confirm}'`

        if(validator(this.state.dataInit)) {
            Swal.fire({html: "برای تغییر رمز عبور اطمینان دارید ?", icon: "question", showCancelButton: true, confirmButtonText: "بله", cancelButtonText: "خیر", cancelButtonColor: "#dc3545", showConfirmButton: true})
            .then(res => {
                if (res.value) {
                    this.setState({loadingStatus: true})
                    mainApi.post(serialize(this.state.data))
                    .then(response => {
                        this.setState({loadingStatus: false})
                        let data =  original(response.data, false)

                        if (data[0].s_result === "1") {
                            this.setState({dataInit: {username: '', old: '', newPass: '', confirm: ''}})
                            Swal.fire({icon: 'success', title: 'موفق آمیز', text: "کاربر گرامی عملیات با موفقیت صورت گرفت.", showConfirmButton: false, timer: 2000})
                        } else {
                            Swal.fire({icon: 'error', title: 'نا موفق', text: "کاربر گرامی عملیات نا موفق بود.", showConfirmButton: false, timer: 2000})
                        }
                    })
                    .catch(err => {
                        this.setState({loadingStatus: false})
                        Swal.fire({icon: 'error', text: err, confirmButtonText: 'Ok'})
                    })
                }
            })
        } else {
            Swal.fire({icon: 'error', title: 'خطای اعتبار سنجی', text: 'اطلاعات فرم را تکمیل نمایید.', showConfirmButton: false, timer: 2000})
        }
    }
}

export default ChangePasswordForm