import React, {PureComponent} from "react"
import Swal from 'sweetalert2'
import mainApi from './../../../api/mainApi'
import {serialize, original, sResultCheck} from './../../../functions/helper'
import ComboReport from "./combobox/ComboReport"
import ComboServices from "./combobox/ComboServices"
import ComboExperts from "./combobox/ComboExperts"
import ComboBanks from "./combobox/ComboBanks"
import ComboPayments from "./combobox/ComboPayments"
import ComboPersons from "./combobox/ComboPersons"
import LoadingElement from "./../../loadings/LoadingElement"
import Validation from "./../../../modules/Validation"
import InputMask from 'react-input-mask';
import {Accordion, Button} from "react-bootstrap"

class FormSearch extends PureComponent
{
    state = {
        data: { id: "", sp_param: "", Login_User_Token: "", Login_User_cp: ""},
        dateFrom: "",
        dateTo: "",
        timeFrom: "",
        timeTo: "",
        person: "",
        expert: "",
        service: "",
        payment: "",
        bank: "",
        user: "",
        desc: "",
        loadingStatus: false,

        errors: {}
    }

    dateFromHandler(e) {this.setState({...this.state, dateFrom: e.target.value})}
    dateTomHandler(e) {this.setState({...this.state, dateTo: e.target.value})}
    timeFromHandler(e) {this.setState({...this.state, timeFrom: e.target.value})}
    timeToHandler(e) {this.setState({...this.state, timeTo: e.target.value})}
    personHandler(person) {this.state.person = person}
    expertHandler(expert) {this.state.expert = expert}
    serviceHandler(service) {this.state.service = service}
    reportHandler(report) {this.state.data.id = report}
    bankHandler(bank) {this.state.bank = bank}
    paymentHandler(payment) {this.state.payment = payment}
    userHandler(e) {this.setState({...this.state, user: e.target.value})}
    descHandler(e) {this.setState({...this.state, desc: e.target.value})}

    searchHandler()
    {
        let valid = Validation.make(this.state, [
			{dateFrom: ["required", "date"]},
			{dateTo: ["required", "date"]}
		])

		if (! valid) {
            this.setState({errors: Validation.getErrors()})
            Swal.fire({position: "bottom", html: `<i class="ion-android-warning text-danger"></i><span class="text-muted">خطا های فرم را بر طرف نمایید.</span>`, showConfirmButton: false, timer: 2000})
			return
        }

        this.setState({errors: {}})
        let {dateFrom, dateTo, timeFrom, timeTo, person, expert, service, payment, bank, user, desc} = this.state

        this.state.data.sp_param = `'${dateFrom}','${dateTo}','${timeFrom}','${timeTo}','${person}','${expert}','${service}','${payment}','${bank}','','','${user}','','','${desc}','${window.localStorage.getItem('user_login_cp')}'`

        this.state.data.Login_User_Token = window.localStorage.getItem('user_login_token')
        this.state.data.Login_User_cp = window.localStorage.getItem('user_login_cp')
        
        this.setState({loadingStatus: true})
        mainApi.post(serialize(this.state.data))
                .then(response => {
                    let data = original(response.data, false)
                    
                    if (sResultCheck(data)) {
                        let titles = []
                        Object.entries(data[0]).forEach(([key, val]) => {
                            titles.push(key)
                        })

                        this.props.titlesHandler(titles)
                        this.props.itemsHandler(Object.entries(data).map(item => item[1]))
                        this.props.handleShow()
                    }

                    this.setState({loadingStatus: false})
                })
                .catch(err => {
                    this.setState({loadingStatus: false})
                    Swal.fire({icon: 'error', text: err, confirmButtonText: 'متوجه شدم'})
                })
    }

    render()
    {
        let {dateFrom, dateTo, timeFrom, timeTo, person, expert, service, payment, bank, user, desc, loadingStatus, errors} = this.state

        return (
            <>
                <h4 className="text-muted text-right">
                    <i className="ion-stats-bars"></i>
                    گزارشات
                </h4>

                <hr />

                <div className="form-row text-right">
                    <section className="col-lg-3 form-group">
                        <label>از تاریخ<small className="text-danger">*</small></label>
                        <InputMask maskChar="_" className="form-control form-control-lg text-left my-dir-ltr" mask="9999/99/99" onChange={(e) => this.dateFromHandler(e)} value={dateFrom} disabled={loadingStatus ? 'disabled' : ''} />
                        {
                            errors.hasOwnProperty('dateFrom')
                                ? <small className="text-danger my-animate-element">{errors.dateFrom}</small>
                                : ""
                        }
                    </section>

                    <section className="col-lg-3 form-group">
                        <label>تا تاریخ<small className="text-danger">*</small></label>
                        <InputMask maskChar="_" className="form-control form-control-lg text-left my-dir-ltr" mask="9999/99/99" onChange={(e) => this.dateTomHandler(e)} value={dateTo} disabled={loadingStatus ? 'disabled' : ''} />
                        {
                            errors.hasOwnProperty('dateTo')
                                ? <small className="text-danger my-animate-element">{errors.dateTo}</small>
                                : ""
                        }
                    </section>

                    <section className="col-lg-6 form-group">
                        <label>گزارش<small className="text-danger">*</small></label>
                        <ComboReport disabled={loadingStatus ? true : false} reportHandler={this.reportHandler.bind(this)} />
                    </section>
                </div>

                

                <Accordion defaultActiveKey="">
                    <div className="text-right">
                        <Accordion.Toggle as={Button} variant="link" eventKey="0" className="text-decoration-none px-0">
                            <div className="text-info">
                                <i className="ion-android-settings"></i>
                                تنظیمات بیشتر
                            </div>
                        </Accordion.Toggle>
                    </div>


                    <Accordion.Collapse eventKey="0">
                        <div>
                            <div className="form-row text-right">
                                <section className="col-lg-3 form-group">
                                    <label>از زمان</label>
                                    <input type="text" value={timeFrom} onChange={(e) => this.timeFromHandler(e)} disabled={loadingStatus ? 'disabled' : ''} className="form-control form-control-lg" />
                                </section>

                                <section className="col-lg-3 form-group">
                                    <label>تا زمان</label>
                                    <input type="text" value={timeTo} onChange={(e) => this.timeToHandler(e)} disabled={loadingStatus ? 'disabled' : ''} className="form-control form-control-lg" />
                                </section>

                                <section className="col-lg-3 form-group">
                                    <label>شخص</label>
                                    <ComboPersons disabled={loadingStatus ? true : false} personHandler={this.personHandler.bind(this)} />
                                </section>

                                <section className="col-lg-3 form-group">
                                    <label>متخصص</label>
                                    <ComboExperts disabled={loadingStatus ? true : false} expertHandler={this.expertHandler.bind(this)} />
                                </section>
                            </div>

                            <div className="form-row text-right">
                                <section className="col-lg-3 form-group">
                                    <label>سرویس</label>
                                    <ComboServices disabled={loadingStatus ? true : false} serviceHandler={this.serviceHandler.bind(this)} />
                                </section>

                                <section className="col-lg-3 form-group">
                                    <label>نوع پرداخت</label>
                                    <ComboPayments disabled={loadingStatus ? true : false} paymentHandler={this.paymentHandler.bind(this)} />
                                </section>

                                <section className="col-lg-3 form-group">
                                    <label>بانک</label>
                                    <ComboBanks disabled={loadingStatus ? true : false} bankHandler={this.bankHandler.bind(this)} />
                                </section>

                                <section className="col-lg-3 form-group">
                                    <label>کاربر</label>
                                    <input type="text" value={user} onChange={(e) => this.userHandler(e)} disabled={loadingStatus ? 'disabled' : ''} className="form-control form-control-lg" />
                                </section>
                            </div>

                            <div className="form-row text-right">
                                <section className="col form-group">
                                    <label>شرح</label>
                                    <input type="text" value={desc} onChange={(e) => this.descHandler(e)} disabled={loadingStatus ? 'disabled' : ''} className="form-control form-control-lg" />
                                </section>
                            </div>
                        </div>
                    </Accordion.Collapse>
                </Accordion>

                <div className="form-row mt-3">
                    <section className="col-sm-12 col-lg-3 form-group">
                        <button onClick={() => this.searchHandler()} className="btn btn-lg btn-block btn-success" disabled={loadingStatus ? 'disabled' : ''}>
                            {
                                loadingStatus 
                                    ?	<LoadingElement varient="button" />
                                    :	<><i className="ion-search" style={{fontSize: "16px"}}></i>جستجو</>
                            }
                        </button>
                    </section>
                </div>
            </>
        )
    }
}

export default FormSearch