import React, {PureComponent} from "react"
import {connect} from "react-redux"
import ComboDays from "./combobox/ComboDays"
import ComboServices from "./combobox/ComboServices"
import ComboExperts from "./combobox/ComboExperts"
import LoadingElement from "./../../loadings/LoadingElement"
import BookableFutureModal from "./BookableFutureModal"
import AllModalShow from "./AllModalShow"
import {setBookableTimes, setFutureTimes, setAllTimes, setFrom, setTo, setDay, setService, setExpert} from "./../../../actions"
import Swal from 'sweetalert2'
import mainApi from './../../../api/mainApi'
import {serialize, original} from './../../../functions/helper'
import Validation from "./../../../modules/Validation"
import InputMask from 'react-input-mask';

class FormSearch extends PureComponent
{
    state = {
        bookableFutureModalShow: false,
        allModalShow: false,

        loadingStatus: false,
        loadingStatusAll: false,

        errors: {}
    }

    bookableFutureModalCloseHandler(){this.setState({bookableFutureModalShow: false})}
    allModalCloseHandler(){this.setState({allModalShow: false})}

    searchHandler()
    {
        let valid = Validation.make(this.props.dataSearch, [
			{from: ["required", "date"]},
			{to: ["required", "date"]}
		])

		if (! valid) {
            this.setState({errors: Validation.getErrors()})
            Swal.fire({position: "bottom", html: `<i class="ion-android-warning text-danger"></i><span class="text-muted">خطا های فرم را بر طرف نمایید.</span>`, showConfirmButton: false, timer: 2000})
			return
        }
        
        this.setState({errors: {}})
        this.getSetBookableTimes()
        this.getSetFutureTimes()
    }

    getSetBookableTimes()
    {
        let {dataBookableTimes, dataSearch} = this.props
        let {from, to, day, service, expert} = dataSearch

        dataBookableTimes.sp_param = `'${from}','${to}','${day}','${service}','${expert}','${window.localStorage.getItem('user_login_cp')}'`
        dataBookableTimes.Login_User_Token = window.localStorage.getItem('user_login_token')
        dataBookableTimes.Login_User_cp = window.localStorage.getItem('user_login_cp')

        mainApi.post(serialize(dataBookableTimes))
        .then(response => {
            let data =  original(response.data, false)
            this.props.setBookableTimes(data)
        })
        .catch(err => {
            this.setState({loadingStatus: false})
            Swal.fire({icon: 'error', text: err, confirmButtonText: 'متوجه شدم'})
        })
    }

    getSetFutureTimes()
    {
        let {dataFutureTimes, dataSearch} = this.props

        dataFutureTimes.Login_User_Token = window.localStorage.getItem('user_login_token')
        dataFutureTimes.Login_User_cp = window.localStorage.getItem('user_login_cp')
        dataFutureTimes.sp_param = `'${window.localStorage.getItem('user_login_cp')}','${dataSearch.from}'`

        this.setState({loadingStatus: true})
        mainApi.post(serialize(dataFutureTimes))
        .then(response => {
            this.setState({loadingStatus: false})
            let data =  original(response.data, false)
            this.props.setFutureTimes(data)
            this.setState({bookableFutureModalShow: true})
        })
        .catch(err => {
            this.setState({loadingStatus: false})
            Swal.fire({icon: 'error', text: err, confirmButtonText: 'متوجه شدم'})
        })
    }

    getSetAllTimesHandler()
    {
        let {dataAllTimes} = this.props

        dataAllTimes.Login_User_Token = window.localStorage.getItem('user_login_token')
        dataAllTimes.Login_User_cp = window.localStorage.getItem('user_login_cp')
        dataAllTimes.sp_param = `'${window.localStorage.getItem('user_login_cp')}',''`

        this.setState({loadingStatusAll: true})
        mainApi.post(serialize(dataAllTimes))
        .then(response => {
            this.setState({loadingStatusAll: false})
            let data =  original(response.data, false)
            this.props.setAllTimes(data)

            this.setState({allModalShow: true})
        })
        .catch(err => {
            this.setState({loadingStatusAll: false})
            Swal.fire({icon: 'error', text: err, confirmButtonText: 'متوجه شدم'})
        })
    }

    render()
    {
        let {loadingStatus, loadingStatusAll, errors} = this.state
        let {setFrom, setTo, dataSearch} = this.props

        return (
            <>
                <h4 className="text-muted text-right">
                    <i className="ion-android-calendar"></i>
                    نوبت دهی
                </h4>

                <hr />

                <div className="form-row text-right">
                    <div className="form-group col-lg-4">
                        <label>از تاریخ<small className="text-danger">*</small></label>
                        <InputMask maskChar="_" className="form-control form-control-lg text-left my-dir-ltr" mask="9999/99/99" onChange={(e) => setFrom(e.target.value)} value={dataSearch.from} disabled={loadingStatus ? 'disabled' : ''} />
                        {
                            errors.hasOwnProperty('from')
                                ? <small className="text-danger my-animate-element">{errors.from}</small>
                                : ""
                        }
                    </div>

                    <div className="form-group col-lg-4">
                        <label>تا تاریخ<small className="text-danger">*</small></label>
                        <InputMask maskChar="_" className="form-control form-control-lg text-left my-dir-ltr" mask="9999/99/99" onChange={(e) => setTo(e.target.value)} disabled={loadingStatus ? 'disabled' : ''} value={dataSearch.to} />
                        {
                            errors.hasOwnProperty('to')
                                ? <small className="text-danger my-animate-element">{errors.to}</small>
                                : ""
                        }
                    </div>

                    <div className="form-group col-lg-4">
                        <label>روز هفته<small className="text-danger">*</small></label>
                        <ComboDays disabled={loadingStatus ? true : false} />
                    </div>
                </div>

                <div className="form-row text-right">
                    <div className="form-group col-lg-6">
                        <label>سرویس<small className="text-danger">*</small></label>
                        <ComboServices disabled={loadingStatus ? true : false} />
                    </div>

                    <div className="form-group col-lg-6">
                        <label>تخصص<small className="text-danger">*</small></label>
                        <ComboExperts disabled={loadingStatus ? true : false} />
                    </div>
                </div>

                <div className="form-row mt-4">
                    <div className="col-lg-3 mt-2">
                        <div className="form-group">
                            <button onClick={() => this.searchHandler()} className="btn btn-lg btn-block btn-success" disabled={loadingStatus || loadingStatusAll ? 'disabled' : ''}>
                                {
                                    loadingStatus 
                                        ?	<LoadingElement varient="button" />
                                        :	<><i className="ion-search" style={{fontSize: "16px", top: "2px"}}></i>جستجو</>
                                }
                            </button>
                        </div>
                    </div>

                    <div className="col-lg-3 mt-2">
                        <div className="form-group">
                            <button onClick={() => this.getSetAllTimesHandler()} className="btn btn-lg btn-block btn-outline-secondary" disabled={loadingStatusAll || loadingStatus ? 'disabled' : ''}>
                                {
                                    loadingStatusAll 
                                        ?	<LoadingElement varient="button" />
                                        :   <><i className="ion-ios-list-outline" style={{fontSize: "16px", top: "2px"}}></i>کل وقت ها</>
                                }
                            </button>
                        </div>
                    </div>
                </div>

                <BookableFutureModal searchHandler={this.searchHandler.bind(this)} show={this.state.bookableFutureModalShow} bookableFutureModalCloseHandler={this.bookableFutureModalCloseHandler.bind(this)} {...this.state} />
                <AllModalShow show={this.state.allModalShow} allModalCloseHandler={this.allModalCloseHandler.bind(this)} {...this.state} />
            </>
        )
    }
}

const mapStateToProps = state => {
    return {
        dataBookableTimes: state.reservation.dataBookableTimes,
        dataFutureTimes: state.reservation.dataFutureTimes,
        dataAllTimes: state.reservation.dataAllTimes,

        bookableTimes: state.reservation.bookableTimes,
        futureTimes: state.reservation.futureTimes,
        allTimes: state.reservation.allTimes,
        dataSearch: state.reservation.dataSearch
    }
}

const mapDispatchToProps = dispatch => {
    return {
        setBookableTimes: bookableTimes => dispatch(setBookableTimes(bookableTimes)),
        setFutureTimes: futureTimes => dispatch(setFutureTimes(futureTimes)),
        setAllTimes: allTimes => dispatch(setAllTimes(allTimes)),

        setFrom: from => dispatch(setFrom(from)),
        setTo: to => dispatch(setTo(to)),
        setDay: day => dispatch(setDay(day)),
        setService: service => dispatch(setService(service)),
        setExpert: expert => dispatch(setExpert(expert))
    }
}

export default connect(mapStateToProps, mapDispatchToProps)(FormSearch)