import React, {PureComponent} from "react"
import {connect} from "react-redux"
import {setProgressBar, resetData, setFname, setLname, setFather, setDateBirth, setCodeNational} from "./../../actions"
import Swal from "sweetalert2"
import Validation from "./../../modules/Validation"
import InputMask from 'react-input-mask'


class StepOne extends PureComponent
{    
    state = {
        errors: {}
    }

    nextHandler()
	{
        let valid = Validation.make(this.props.data, [
			{fname: ["required"]},
			{lname: ["required"]},
			{father: ["required"]},
			{dateBirth: ["required", "date"]},
			{codeNational: ["required", "tenDigitCode"]}
		])

		if (! valid) {
            this.setState({errors: Validation.getErrors()})
            Swal.fire({position: "bottom", html: `<i class="ion-android-warning text-danger"></i><span class="text-muted">خطا های فرم را بر طرف نمایید.</span>`, showConfirmButton: false, timer: 2000})
			return
        }

        this.setState({errors: {}})
        this.props.setProgressBar(25)
        window.scrollTo(0, 0)
    }
    
    /*resetData()
    {
        this.props.resetData()
        window.scrollTo(0, 0)
        document.querySelector(".card-body-register input").focus()
    }*/

    render()
    {
        let {setFname, setLname, setFather, setDateBirth, setCodeNational, data, progressBar, resetData} = this.props
        let {errors} = this.state
        
        return (
            <>
                <div className={`card-body-register ${progressBar == 0 ? "active" : ""}`}>
                    <main className="card-body">
                        <div className="form-row text-muted">
                            <section className="col-lg-6 form-group text-right">
                                <label>نام<small className="text-danger">*</small></label>
                                <input onChange={(e) => setFname(e.target.value)} value={data.fname} className="form-control form-control-lg" />
                                {
                                    errors.hasOwnProperty('fname')
                                        ? <small className="text-danger my-animate-element">{errors.fname}</small>
                                        : ""
                                }
                            </section>
                            
                            <section className="col-lg-6 form-group text-right">
                                <label>نام خانوادگی<small className="text-danger">*</small></label>
                                <input onChange={(e) => setLname(e.target.value)} value={data.lname} className="form-control form-control-lg" />
                                {
                                    errors.hasOwnProperty('lname')
                                        ? <small className="text-danger my-animate-element">{errors.lname}</small>
                                        : ""
                                }
                            </section>
                        </div>
                        
                        <div className="form-row text-muted">
                            <section className="col-lg-6 form-group text-right">
                                <label>نام پدر<small className="text-danger">*</small></label>
                                <input onChange={(e) => setFather(e.target.value)} value={data.father} className="form-control form-control-lg" />
                                {
                                    errors.hasOwnProperty('father')
                                        ? <small className="text-danger my-animate-element">{errors.father}</small>
                                        : ""
                                }
                            </section>
                        
                            <section className="col-lg-6 form-group text-right position-relative">
                                <label>تاریخ تولد<small className="text-danger">*</small></label>
                                <InputMask maskChar="_" className="form-control form-control-lg text-left my-dir-ltr" mask="9999/99/99" onChange={(e) => setDateBirth(e.target.value)} value={data.dateBirth} />
                                {
                                    errors.hasOwnProperty('dateBirth')
                                        ? <small className="text-danger my-animate-element">{errors.dateBirth}</small>
                                        : ""
                                }
                            </section>
                        </div>

                        <div className="form-row text-muted">
                            <section className="col-lg-12 form-group text-right">
                                <label>کد ملی<small className="text-danger">*</small></label>
                                <InputMask maskChar="" className="form-control form-control-lg text-left my-dir-ltr" mask="9999999999" onChange={(e) => setCodeNational(e.target.value)} value={data.codeNational} />
                                {
                                    errors.hasOwnProperty('codeNational')
                                        ? <small className="text-danger my-animate-element">{errors.codeNational}</small>
                                        : ""
                                }
                            </section>
                        </div>
                    </main>
                    
                    <footer className="card-footer text-left d-flex flex-row-reverse flex-wrap">
                        <button onClick={() => this.nextHandler()} className="btn btn-lg btn-info mr-2 mt-1">بعدی</button>
                        {/* <button onClick={() => this.resetData()} className="btn btn-outline-secondary mr-2 mt-1">بازنویسی</button> */}
                    </footer>
                </div>
            </>
        )
    }
}

const mapStateToProps = state => {
    return {
        progressBar: state.register.progressBar,
        data: state.register.data
    }
}

const mapDispatchToProps = dispatch => {
    return {
        setProgressBar: num => dispatch(setProgressBar(num)),
        resetData: num => dispatch(resetData()),
        setFname: val => dispatch(setFname(val)),
        setLname: val => dispatch(setLname(val)),
        setFather: val => dispatch(setFather(val)),
        setDateBirth: val => dispatch(setDateBirth(val)),
        setCodeNational: val => dispatch(setCodeNational(val))
    }
}

export default connect(mapStateToProps, mapDispatchToProps)(StepOne)