import React, {PureComponent} from "react"
import {connect} from "react-redux"
import {setProgressBar, resetData, setEmail, setWebsite, setCodePostal, setAddress} from "./../../actions"
import Swal from "sweetalert2"
import Validation from "./../../modules/Validation"
import InputMask from 'react-input-mask'

class StepThree extends PureComponent
{    
    state = {
        errors: {}
    }

    nextHandler()
	{
        let valid = Validation.make(this.props.data, [
			{email: ["email"]},
			{codePostal: ["tenDigitCode"]},
		])

		if (! valid) {
            this.setState({errors: Validation.getErrors()})
            Swal.fire({position: "bottom", html: `<i class="ion-android-warning text-danger"></i><span class="text-muted">خطا های فرم را بر طرف نمایید.</span>`, showConfirmButton: false, timer: 2000})
			return
        }

        this.props.setProgressBar(75)
        window.scrollTo(0, 0)
    }
    
    /*resetData()
    {
        this.props.resetData()
        setTimeout(() => {
            window.scrollTo(0, 0)
            document.querySelector(".card-body-register input").focus()
        }, 10)
    }*/

    render()
    {
        let {setEmail, setWebsite, setCodePostal, setAddress, data, progressBar} = this.props
        let {errors} = this.state
        
        return (
            <>
                <div className={`card-body-register ${progressBar == 50 ? "active" : ""}`}>
                    <main className="card-body">
                        <div className="form-row text-muted">
                            <section className="col-lg-6 form-group text-right">
                                <label>ایمیل</label>
                                <input onChange={(e) => setEmail(e.target.value)} value={data.email} className="form-control form-control-lg text-left" style={{direction: "ltr"}} />
                                {
                                    errors.hasOwnProperty('email')
                                        ? <small className="text-danger my-animate-element">{errors.email}</small>
                                        : ""
                                }
                            </section>
                            
                            <section className="col-lg-6 form-group text-right">
                                <label>وب سایت</label>
                                <input onChange={(e) => setWebsite(e.target.value)} value={data.setWebsite} className="form-control form-control-lg text-left" style={{direction: "ltr"}} />
                            </section>
                        </div>
                        
                        <div className="form-row text-muted">
                            <section className="col form-group text-right">
                                <label>کد پستی</label>
                                <InputMask maskChar="" className="form-control form-control-lg text-left my-dir-ltr" mask="9999999999" onChange={(e) => setCodePostal(e.target.value)} value={data.setCodePostal} />
                                {
                                    errors.hasOwnProperty('codePostal')
                                        ? <small className="text-danger my-animate-element">{errors.codePostal}</small>
                                        : ""
                                }
                            </section>
                        </div>

                        <div className="form-row text-muted">
                            <section className="col form-group text-right">
                                <label>آدرس</label>
                                <input onChange={(e) => setAddress(e.target.value)} value={data.setAddress} type="text" className="form-control form-control-lg" />
                            </section>
                        </div>
                    </main>
                    
                    <footer className="card-footer text-left d-flex flex-row-reverse flex-wrap">
                        <button onClick={() => this.nextHandler()} className="btn btn-lg btn-info mr-2 mt-1">بعدی</button>
                        <button onClick={() => {this.props.setProgressBar(25); window.scrollTo(0, 0);}} className="btn btn-lg btn-warning text-light mr-2 mt-1">قبلی</button>
                        {/* <button onClick={() => this.resetData()} className="btn btn-outline-secondary mr-2 mt-1">بازنویسی</button> */}
                    </footer>
                </div>
            </>
        )
    }
}

const mapStateToProps = state => {
    return {
        progressBar: state.register.progressBar,
        data: state.register.data
    }
}

const mapDispatchToProps = dispatch => {
    return {
        setProgressBar: num => dispatch(setProgressBar(num)),
        resetData: num => dispatch(resetData()),
        setEmail: val => dispatch(setEmail(val)),
        setWebsite: val => dispatch(setWebsite(val)),
        setCodePostal: val => dispatch(setCodePostal(val)),
        setAddress: val => dispatch(setAddress(val)),
    }
}

export default connect(mapStateToProps, mapDispatchToProps)(StepThree)