import React, {PureComponent} from "react"
import {connect} from "react-redux"
import {setProgressBar, resetData, setMobile, setTel, setUsername, setPassword, setConfirm} from "./../../actions"
import Swal from "sweetalert2"
import Validation from "./../../modules/Validation"
import InputMask from 'react-input-mask'

class StepTwo extends PureComponent
{    
    state = {
        errors: {}
    }

    nextHandler()
	{
        let valid = Validation.make(this.props.data, [
			{mobile: ["required", "mobile"]},
			{tel: ["required", "tel"]},
			{username: ["required", "min:4"]},
			{password: ["required", "min:4"]},
			{confirm: ["required", "confirm:password"]}
		])

		if (! valid) {
            this.setState({errors: Validation.getErrors()})
            Swal.fire({position: "bottom", html: `<i class="ion-android-warning text-danger"></i><span class="text-muted">خطا های فرم را بر طرف نمایید.</span>`, showConfirmButton: false, timer: 2000})
			return
        }

        this.setState({errors: {}})
        this.props.setProgressBar(50)
        window.scrollTo(0, 0)
    }
    
    /*resetData()
    {
        this.props.resetData()
        setTimeout(() => {
            window.scrollTo(0, 0)
            document.querySelector(".card-body-register input").focus()
        }, 10)
    }*/

    render()
    {
        let {setMobile, setTel, setUsername, setPassword, setConfirm, data, progressBar} = this.props
        let {errors} = this.state
        
        return (
            <>
                <div className={`card-body-register ${progressBar == 25 ? "active" : ""}`}>
                    <main className="card-body">
                        <div className="form-row text-muted">
                            <section className="col-lg-6 form-group text-right">
                                <label>تلفن همراه<small className="text-danger">*</small></label>
                                <InputMask maskChar="" className="form-control form-control-lg text-left my-dir-ltr" mask="99999999999" onChange={(e) => setMobile(e.target.value)} value={data.mobile} />
                                {
                                    errors.hasOwnProperty('mobile')
                                        ? <small className="text-danger my-animate-element">{errors.mobile}</small>
                                        : ""
                                }
                            </section>
                            
                            <section className="col-lg-6 form-group text-right">
                                <label>تلفن ثابت<small className="text-danger">*</small></label>
                                <InputMask maskChar="" className="form-control form-control-lg text-left my-dir-ltr" mask="99999999999" onChange={(e) => setTel(e.target.value)} value={data.tel} />
                                {
                                    errors.hasOwnProperty('tel')
                                        ? <small className="text-danger my-animate-element">{errors.tel}</small>
                                        : ""
                                }
                            </section>
                        </div>
                        
                        <div className="form-row text-muted">
                            <section className="col form-group text-right">
                                <label>نام کاربری<small className="text-danger">*</small></label>
                                <input onChange={(e) => setUsername(e.target.value)} value={data.username} type="text" className="form-control form-control-lg text-left" style={{direction: "ltr"}} />
                                {
                                    errors.hasOwnProperty('username')
                                        ? <small className="text-danger my-animate-element">{errors.username}</small>
                                        : ""
                                }

                                    <>
                                        <div className="text-info small">نام کاربری را با حروف لاتین وارد نمایید.</div>
                                        <small className="text-info">نام کاربری حداقل باید 4 حرف باشد.</small>
                                    </>
                            </section>
                        </div>

                        <div className="form-row text-muted">
                            <section className="col-lg-6 form-group text-right">
                                <label>رمز عبور<small className="text-danger">*</small></label>
                                <input onChange={(e) => setPassword(e.target.value)} value={data.password} type="password" className="form-control form-control-lg text-left" style={{direction: "ltr"}} />
                                {
                                    errors.hasOwnProperty('password')
                                        ? <small className="text-danger my-animate-element">{errors.password}</small>
                                        : ""
                                }
                                <div className="text-info small">رمز عبور حداقل باید 4 حرف باشد.</div>
                            </section>

                            <section className="col-lg-6 form-group text-right">
                                <label>تکرار رمز عبور<small className="text-danger">*</small></label>
                                <input onChange={(e) => setConfirm(e.target.value)} value={data.confirm} type="password" className="form-control form-control-lg text-left" style={{direction: "ltr"}} />
                                {
                                    errors.hasOwnProperty('confirm')
                                        ? <small className="text-danger my-animate-element">{errors.confirm}</small>
                                        : ""
                                }
                            </section>
                        </div>
                    </main>
                    
                    <footer className="card-footer text-left d-flex flex-row-reverse flex-wrap">
                        <button onClick={() => this.nextHandler()} className="btn btn-lg btn-info mr-2 mt-1">بعدی</button>
                        <button onClick={() => {this.props.setProgressBar(0); window.scrollTo(0, 0);}} className="btn btn-lg btn-warning text-light mr-2 mt-1">قبلی</button>
                        {/* <button onClick={() => this.resetData()} className="btn btn-outline-secondary mr-2 mt-1">بازنویسی</button> */}
                    </footer>
                </div>
            </>
        )
    }
}

const mapStateToProps = state => {
    return {
        progressBar: state.register.progressBar,
        data: state.register.data
    }
}

const mapDispatchToProps = dispatch => {
    return {
        setProgressBar: num => dispatch(setProgressBar(num)),
        resetData: num => dispatch(resetData()),
        setMobile: val => dispatch(setMobile(val)),
        setTel: val => dispatch(setTel(val)),
        setUsername: val => dispatch(setUsername(val)),
        setPassword: val => dispatch(setPassword(val)),
        setConfirm: val => dispatch(setConfirm(val))
    }
}

export default connect(mapStateToProps, mapDispatchToProps)(StepTwo)