import React, {PureComponent} from "react"
import {Route, Switch} from "react-router-dom";
import routes from "./../routes"
import Navbar from "./../components/layouts/user/Navbar"
import Footer from "./../components/layouts/user/Footer"
import NotFound from "./../views/NotFound"
import Panel from "./../views/Panel"
import {showFlash} from "./../functions/helper"

class User extends PureComponent
{
    getRoutes(routes)
    {
        return routes.map((prop, key) => {
            if (prop.layout === "/user") {
                return (
                    <Route
                        exact
                        path={prop.path}
                        render={props => (
                            <prop.component {...props} />
                        )}
                        key={key}
                    />
                )
            } else {
                return null;
            }
        });
    }

    render()
    {
        return (
            <>
                <Navbar {...this.props} />

                <div className="my-4" style={{minHeight: "calc(100vh - 200px)"}}>
                    <Switch>
                        {this.getRoutes(routes)}
                        <Route exact path="/panel/:type" component={Panel} />
                        <Route exact component={NotFound} />
                    </Switch>
                </div>

                <Footer {...this.props} />
            </>
        )
    }

    componentDidMount()
    {
        showFlash("no-auth")
    }
}

export default User