import React from 'react'
import {connect} from 'react-redux'
import Swal from 'sweetalert2'
import mainApi from './../api/mainApi'
import LoadingElement from "./../components/loadings/LoadingElement"
import {serialize, original} from './../functions/helper'
import {loginRequest} from './../actions'
import Validation from "./../modules/Validation"

class Login extends React.PureComponent
{
	state = {
		data: {id: 1112, username: '', password: ''},
		connectingStatus: false,

		errors: {},
	}

	constructor (props)
	{
		super(props)

		if (props.auth && 
				window.localStorage.hasOwnProperty('user_login_token') && 
					window.localStorage.hasOwnProperty('user_login_cp')) {
			props.history.push("/")
		}
	}
	
	usernameHandler = (e) => this.setState({data: {...this.state.data, username: e.target.value}})
	passwordHandler = (e) => this.setState({data: {...this.state.data, password: e.target.value}})
	
	submitHandler = (e) => {
		e.preventDefault()

		let valid = Validation.make(this.state.data, [
			{username: ["required"]},
			{password: ["required"]}
		])

		if (! valid) {
			this.setState({errors: Validation.getErrors()})
			Swal.fire({position: "bottom", html: `<i class="ion-android-warning text-danger"></i><span class="text-muted">خطا های فرم را بر طرف نمایید.</span>`, showConfirmButton: false, timer: 2000})
			return
		}

		this.setState({errors: {}})
		let {data} = this.state
		
		this.setState({connectingStatus: true})
		mainApi.post(serialize(data))
			.then(response => {
				let {user_login_cp, user_login_message, user_login_token, user_login_np} = original(response.data)
				
				if (user_login_cp !== '0') {
					window.localStorage.setItem('user_login_cp', user_login_cp);
					window.localStorage.setItem('user_login_token', user_login_token);
					window.localStorage.setItem('user_login_np', user_login_np);
					window.localStorage.setItem('username', this.state.data.username);
					this.props.login()
					this.props.history.push('/panel')
					
				} else {
					this.setState({connectingStatus: false})
					Swal.fire({icon: 'error', text: user_login_message, confirmButtonText: 'متوجه شدم'})
				}
			})
			.catch(err => {
				this.setState({connectingStatus: false})
				Swal.fire({icon: 'error', text: err, confirmButtonText: 'متوجه شدم'})
			})
	}
	
	render ()
	{	
		let {username, password} = this.state.data
		let {connectingStatus, errors} = this.state
		
		return (
			<div className="container my-animate-page">
				<div className="row">
					<div className="col col-lg-5 m-auto">
						<form onSubmit={this.submitHandler} className="card">
							<header className="card-header text-muted text-right h4">
								<i className="ion-log-in" style={{top: "2px"}}></i>
								ورود به سامانه
							</header>
							
							<main className="card-body">
								<section className="form-group text-right">
									<label className="text-muted">نام کاربری</label>
									<input onChange={this.usernameHandler} value={username} className="form-control form-control-lg text-left text-muted" style={{direction: "ltr"}} disabled={connectingStatus ? 'disabled' : ''} />
									{
										errors.hasOwnProperty('username')
											? <small className="text-danger my-animate-element">{errors.username}</small>
											: ""
									}
								</section>
								
								<section className="form-group text-right">
									<label className="text-muted">رمز عبور</label>
									<input onChange={this.passwordHandler} value={password} type="password" className="form-control form-control-lg text-left text-muted" style={{direction: "ltr"}} disabled={connectingStatus ? 'disabled' : ''} />
									{
										errors.hasOwnProperty('password')
											? <small className="text-danger my-animate-element">{errors.password}</small>
											: ""
									}
								</section>
							</main>
							
							<footer className="card-footer text-left">
								<button className="btn btn-block btn-lg btn-info" disabled={connectingStatus ? 'disabled' : ''}>
									{
										connectingStatus 
											?	<LoadingElement varient="button" />
											:	"ورود"
									}
								</button>
							</footer>
						</form>
					</div>
				</div>
			</div>
		)
	}
}

const mapStateToProps = state => ({auth: state.auth})

const mapDispatchToProps = dispatch => ({
	login: () => dispatch(loginRequest())
})

export default connect(mapStateToProps, mapDispatchToProps)(Login)