import React, {PureComponent} from "react"
import {connect} from 'react-redux'
import {BrowserRouter, Route, Switch} from "react-router-dom"
import Sidebar from "./../components/panel/sidebar"
import routes from "./../routes"
import {logoutRequest} from "./../actions"
import NotFound from "./../views/NotFound"

class Panel extends PureComponent
{
    constructor (props)
	{
		super(props)
		
        if (! props.auth || 
                ! window.localStorage.hasOwnProperty('user_login_token') || 
                    ! window.localStorage.hasOwnProperty('user_login_cp')) {
                        props.logout()
                        props.history.push('/')
        }
	}

    getRoutes(routes)
    {
        return routes.map((prop, key) => {
            if (prop.layout === "/panel") {
                return (
                    <Route
                        exact
                        path={prop.path}
                        render={props => (
                            <prop.component {...props} />
                        )}
                        key={key}
                    />
                )
            } else {
                return null;
            }
        });
    }

    render()
    {
        return (
            <div className="container my-animate-page">
                <div className="row">
                    <BrowserRouter>
                        <div className="col-lg-3">
                            <Sidebar {...this.props} />
                        </div>

                        <div className="col-lg-9 work-area">
                            <Switch>
                                {this.getRoutes(routes)}
                                <Route exact component={NotFound} />
                            </Switch>
                        </div>
                    </BrowserRouter>
                </div>
            </div>
        )
    }
}

const mapStateToProps = state => ({auth: state.auth})

const mapDispatchToProps = dispatch => ({
	logout: () => dispatch(logoutRequest())
})

export default connect(mapStateToProps, mapDispatchToProps)(Panel)